==============
Esmlab.regrid
=============

`Esmlab.regrid` is a lightweight library for regridding in Python. It relies on both `xesmf` and `ESMF` functionaly.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   notebooks/tutorial
   api
   contributing
   changelog


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
